@@ -9,6 +9,8 @@ import utils
 # base patterns always available through having djhcup_core installed
 urlpatterns = patterns('',
     url(r'^$', 'djhcup_core.views.index', name='index'),
+    url(r'^login/$', 'djhcup_core.views.login', name='login'),
+    url(r'^logout/$', 'djhcup_core.views.logout', name='logout'),
 )
 
 
